@@ -3,8 +3,8 @@ import asyncio
 from mini.blockapi.block_observe import ObserveFaceRecognise
 from mini.blockapi.block_sound import PlayTTS
 from mini.dns.dns_browser import WiFiDevice
-from test_connect import test_connect, shutdown
-from test_connect import test_get_device_by_name, test_start_run_program
+from test.test_connect import test_connect, shutdown
+from test.test_connect import test_get_device_by_name, test_start_run_program
 
 
 async def test_ObserveFaceRecognise():
@@ -13,6 +13,7 @@ async def test_ObserveFaceRecognise():
     def handler(msg):
         print(f"{msg}")
         if msg.isSuccess and msg.faceInfos:
+            observer.stop()
             asyncio.create_task(__tts(msg.faceInfos[0].name))
 
     observer.set_handler(handler)
@@ -22,6 +23,7 @@ async def test_ObserveFaceRecognise():
 
 async def __tts(name):
     await PlayTTS(text=f'你好， {name}').execute()
+    asyncio.get_running_loop().run_in_executor(None, asyncio.get_running_loop().stop)
 
 
 if __name__ == '__main__':
