@@ -3,17 +3,17 @@ import asyncio
 from mini.blockapi.block_observe import ObserveInfraredDistance
 from mini.blockapi.block_sound import PlayTTS
 from mini.dns.dns_browser import WiFiDevice
-
-from test_connect import test_connect, shutdown
-from test_connect import test_get_device_by_name, test_start_run_program
+from test.test_connect import test_connect, shutdown
+from test.test_connect import test_get_device_by_name, test_start_run_program
 
 
 async def test_ObserveInfraredDistance():
     observer: ObserveInfraredDistance = ObserveInfraredDistance()
 
     def handler(msg):
-        print("{0}".format(str(msg.distance)))
+        print("distance = {0}".format(str(msg.distance)))
         if msg.distance < 500:
+            observer.stop()
             asyncio.create_task(__tts())
 
     observer.set_handler(handler)
@@ -22,7 +22,9 @@ async def test_ObserveInfraredDistance():
 
 
 async def __tts():
-    await PlayTTS(text="是不是有人在啊， 你是谁啊").execute()
+    result = await PlayTTS(text="是不是有人在啊， 你是谁啊").execute()
+    print(f"tts over {result}")
+    asyncio.get_running_loop().run_in_executor(None, asyncio.get_running_loop().stop)
 
 
 if __name__ == '__main__':
