@@ -1,11 +1,11 @@
 import asyncio
 
+from mini.blockapi.block_expression import ControlBehavior
 from mini.blockapi.block_observe import ObserveRobotPosture
 from mini.blockapi.block_sound import PlayTTS
 from mini.dns.dns_browser import WiFiDevice
-
-from test_connect import test_connect, shutdown
-from test_connect import test_get_device_by_name, test_start_run_program
+from test.test_connect import test_connect, shutdown
+from test.test_connect import test_get_device_by_name, test_start_run_program
 
 
 async def test_ObserveRobotPosture():
@@ -14,6 +14,7 @@ async def test_ObserveRobotPosture():
     def handler(msg):
         print("{0}".format(msg))
         if msg.status == 8 or msg.status == 7:
+            observer.stop()
             asyncio.create_task(__tts())
 
     observer.set_handler(handler)
@@ -23,6 +24,7 @@ async def test_ObserveRobotPosture():
 
 async def __tts():
     await PlayTTS(text="我摔倒了").execute()
+    asyncio.get_running_loop().run_in_executor(None, asyncio.get_running_loop().stop)
 
 
 if __name__ == '__main__':
