@@ -1,8 +1,8 @@
 import asyncio
 
-from blockapi.block_expression import ControlBehavior
-from blockapi.block_observe import ObserveHeadRacket
-from dns.dns_browser import WiFiDevice
+from mini.blockapi.block_expression import ControlBehavior
+from mini.blockapi.block_observe import ObserveHeadRacket
+from mini.dns.dns_browser import WiFiDevice
 from test.test_connect import test_connect, shutdown
 from test.test_connect import test_get_device_by_name, test_start_run_program
 
@@ -11,8 +11,9 @@ async def test_ObserveHeadRacket():
     observer: ObserveHeadRacket = ObserveHeadRacket()
 
     def handler(msg):
+        observer.stop()
         print("{0}".format(str(msg.type)))
-        asyncio.run(__dance())
+        asyncio.create_task(__dance())
 
     observer.set_handler(handler)
     observer.start()
@@ -21,6 +22,7 @@ async def test_ObserveHeadRacket():
 
 async def __dance():
     await ControlBehavior(name="dance_0002").execute()
+    asyncio.get_running_loop().run_in_executor(None, asyncio.get_running_loop().stop)
 
 
 if __name__ == '__main__':
