@@ -2,12 +2,12 @@ import asyncio
 import logging
 
 import mini.mini_sdk as MiniSdk
-from mini.blockapi.block_setup import StartRunProgram, StopRunProgram
+from mini.blockapi.block_setup import StartRunProgram
 from mini.dns.dns_browser import WiFiDevice
 
 
 async def test_get_device_by_name():
-    result = await MiniSdk.get_device_by_name("00022", 10)
+    result = await MiniSdk.get_device_by_name("00018", 10)
     print(f"test_get_device_by_name result:{result}")
     return result
 
@@ -18,10 +18,11 @@ async def test_connect(dev: WiFiDevice):
 
 async def test_start_run_program():
     await StartRunProgram().execute()
+    await asyncio.sleep(6)
 
 
 async def shutdown():
-    await asyncio.sleep(5)
+    await asyncio.sleep(1)
     await MiniSdk.release()
 
 
