@@ -2,7 +2,7 @@
 
 import asyncio
 
-from dns.dns_browser import WiFiDeviceListener, WiFiDevice
+from mini.dns.dns_browser import WiFiDeviceListener, WiFiDevice
 
 
 class MyDeviceListener(WiFiDeviceListener):
@@ -21,11 +21,11 @@ listener = MyDeviceListener()
 
 listener2 = MyDeviceListener()
 
-from channels.websocket_client import ubt_websocket as SocketClient
+from mini.channels.websocket_client import ubt_websocket as SocketClient
 
 print(f'{SocketClient()}')
 
-from dns.dns_browser import browser
+from mini.dns.dns_browser import browser
 
 
 async def test_browser():
